<template>
    <div class="home-container">
        <div style="height: 100%">
            <el-row class="homeCard">
                <div class="basic-line">
                    <span>作业类型：</span>
                    <el-select v-model="params.searchParams.workType" clearable filterable class="input-box" placeholder="作业类型">
                        <el-option v-for="item in workTypeList" :key="item.id" :label="item.name" :value="item.id"></el-option>
                    </el-select>
                </div>
                <div class="basic-line">
                    <span>措施类型：</span>
                    <el-select v-model="params.searchParams.type" clearable filterable class="input-box" placeholder="措施类型">
                        <el-option v-for="item in typeList" :key="item.id" :label="item.name" :value="item.id"></el-option>
                    </el-select>
                </div>
                <div class="basic-line">
                    <span>措施内容：</span>
                    <el-input v-model.trim="params.searchParams.context" class="input-box" placeholder="措施内容"> </el-input>
                </div>
                <div style="padding-bottom: 10px">
                    <el-button type="primary" @click="initSafetyAction">查询</el-button>
                    <el-button plain @click="reset">重置</el-button>
                </div>
            </el-row>
            <div class="homeCard">
                <div class="main-card">
                    <el-row class="cardTop">
                        <el-col :span="24" class="mainCardBtn">
                            <el-button type="primary" size="default" @click="openSafetyActionDialog('新增', {})">新建</el-button>
                            <el-button type="danger"  size="default" @click="deleteMoreSafetyAction" plain>批量删除</el-button>
                        </el-col>
                    </el-row>
                    <el-table ref="multipleTableRef" :data="safetyActionData" style="width: 100%" height="calc(100% - 100px)" :header-cell-style="{ background: '#fafafa' }" @selection-change="handleSelectionChange">
                        <el-table-column type="selection" width="55" />
                        <el-table-column property="workType" label="作业类型">
                            <template slot-scope="scope">
                                <div v-for="item in workTypeList">
                                    <div v-if="scope.row.workType === item.id">
                                        <span>{{item.name}}</span>
                                    </div>
                                </div>
                            </template>
                        </el-table-column>
                        <el-table-column property="type" label="措施类型">
                            <template slot-scope="scope">
                                <div v-for="item in typeList">
                                    <div v-if="scope.row.type === item.id">
                                        <span>{{item.name}}</span>
                                    </div>
                                </div>
                            </template>
                        </el-table-column>
                        <el-table-column property="context" label="措施内容"></el-table-column>
                        <el-table-column prop="correctVal" label="正确值" show-overflow-tooltip>
                            <template slot-scope="scope">
                                <div v-for="item in typeTwoList">
                                    <div v-if="scope.row.correctVal === item.id">
                                        <span>{{item.name}}</span>
                                    </div>
                                </div>
                            </template>
                        </el-table-column>
                        <el-table-column prop="createUname" label="创建人" show-overflow-tooltip></el-table-column>
                        <el-table-column prop="gmtCreate" label="创建时间" show-overflow-tooltip></el-table-column>
                        <el-table-column prop="modifiedUname" label="最后修改人" show-overflow-tooltip></el-table-column>
                        <el-table-column prop="gmtModified" label="最后修改时间" show-overflow-tooltip></el-table-column>
                        <el-table-column fixed="right" label="操作" align="center" width="300">
                            <template slot-scope="scope">
                                <el-button  type="text" @click="openSafetyActionDialog('查看', scope.row)">查看</el-button>
                                <el-button  type="text" @click="openSafetyActionDialog('修改', scope.row)">修改</el-button>
                                <el-button  style="color:red" type="text" @click="deleteSafetyAction(scope.row)">删除</el-button>
                            </template>
                        </el-table-column>
                    </el-table>
                    <br />
                    <el-pagination @size-change="onHandleSizeChange" @current-change="onHandleCurrentChange" :pager-count="5" :page-sizes="[10, 20, 30]" v-model:current-page="params.pageIndex" background v-model:page-size="params.pageSize" layout="total, sizes, prev, pager, next, jumper" :total="total" class="page-position"> </el-pagination>
                </div>
            </div>
        </div>
        <safety-action-dialog ref="safetyActionDialogRef" @refreshSafetyAction="initSafetyAction"></safety-action-dialog>
    </div>
</template>

<script>
import safetyActionDialog from "./components/safetyActionDialog";
import {safetyActionApi} from "../../../../api/safetyAction";
export default {
    name: 'index',
    components: { safetyActionDialog },
    data(){
        return{
            safetyActionData: [],
            total: 0,
            loading: false,
            params: {
                pageIndex: 1,
                pageSize: 10,
                searchParams: {
                    workType: null,
                    type: null,
                    context: null
                }
            },
            workTypeList: [
                { id: 1, name: '动火作业' },
                { id: 2, name: '受限空间作业' },
                { id: 3, name: '吊装作业' },
                { id: 4, name: '动土作业' },
                { id: 5, name: '断路作业' },
                { id: 6, name: '高处作业' },
                { id: 7, name: '临时用电作业' },
                { id: 8, name: '盲板抽堵作业' }
            ],
            typeList: [
                { id: 1, name: '选择' },
                { id: 2, name: '填空' }
            ],
            typeTwoList: [
                { id: 1, name: '是' },
                { id: 2, name: '否' }
            ],
            deleteList: {
                ids: []
            }
        }
    },
    created() {
        this.initSafetyAction()
    },
    methods:{
        async initSafetyAction() {
            let res = await safetyActionApi().getSafetyActionList(this.params);
            if (res.data.code === '200') {
                this.safetyActionData = res.data.data;
                this.total = res.data.total;
            } else {
                this.$message({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        },

        openSafetyActionDialog(type, value) {
            this.$refs.safetyActionDialogRef.showSafetyActionDialog(type, value);
        },

        deleteMoreSafetyAction() {
            this.$confirm(`此操作将永久删除该措施，是否继续?`, '提示', {
                confirmButtonText: '确认',
                cancelButtonText: '取消',
                type: 'warning'
            })
                .then(async () => {
                    let res = await safetyActionApi().deleteSafetyAction(this.deleteList);
                    if (res.data.code === '200') {
                        this.$message({
                            type: 'success',
                            duration: 2000,
                            message: '删除成功'
                        });
                        await this.initSafetyAction();
                    } else {
                        this.$message({
                            type: 'warning',
                            message: res.data.msg
                        });
                    }
                })
                .catch(() => {});
        },
        deleteSafetyAction(row) {
            this.$confirm(`此操作将永久删除该措施，是否继续?`, '提示', {
                confirmButtonText: '确认',
                cancelButtonText: '取消',
                type: 'warning'
            })
                .then(async () => {
                    let res = await safetyActionApi().deleteSafetyAction({ ids: [row.id] });
                    if (res.data.code === '200') {
                        this.deleteList.ids = [];
                        this.$message({
                            type: 'success',
                            duration: 2000,
                            message: '删除成功'
                        });
                        await this.initSafetyAction();
                    } else {
                        this.$message({
                            type: 'warning',
                            message: res.data.msg
                        });
                    }
                })
                .catch(() => {});
        },
        handleSelectionChange(val) {
            this.deleteList.ids = val.map((item) => {
                return item.id;
            });
        },

        parseNumber(value, type) {
            if (type === '作业类型') {
                return this.workTypeList.find((item) => item.id === value).name;
            } else {
                return this.typeList.find((item) => item.id == value).name;
            }
        },

        onHandleSizeChange(val) {
            this.params.pageSize = val;
            this.initSafetyAction()
        },

        onHandleCurrentChange(val) {
            this.params.pageIndex = val;
            this.initSafetyAction()
        },

        reset() {
            this.params = {
                pageIndex: 1,
                pageSize: 10,
                searchParams: {
                    workType: null,
                    type: null,
                    context: null
                }
            };
        },
    },
};
</script>

<style scoped lang="scss">
$homeNavLengh: 8;
.home-container {
    height: calc(100vh - 100px);
    box-sizing: border-box;
    overflow: hidden;
    .homeCard {
        width: 100%;
        padding: 20px;
        box-sizing: border-box;
        background: #fff;
        border-radius: 4px;

        .main-card {
            width: 100%;
            height: 100%;
            .cardTop {
                display: flex;
                align-items: center;
                justify-content: space-between;
                margin-bottom: 20px;
                .mainCardBtn {
                    margin: 0;
                }
            }
            .pageBtn {
                height: 60px;
                display: flex;
                align-items: center;
                justify-content: right;

                .demo-pagination-block + .demo-pagination-block {
                    margin-top: 10px;
                }
                .demo-pagination-block .demonstration {
                    margin-bottom: 16px;
                }
            }
        }
        &:last-of-type {
            height: calc(100% - 100px);
        }
    }
    .el-row {
        display: flex;
        align-items: center;
        margin-bottom: 20px;
        &:last-child {
            margin-bottom: 0;
        }
        .grid-content {
            align-items: center;
            min-height: 36px;
        }

        .topInfo {
            display: flex;
            align-items: center;
            font-size: 16px;
            font-weight: bold;

            & > div {
                white-space: nowrap;
                margin-right: 20px;
            }
        }
    }
}
.stepItem {
    width: 100%;
    display: flex;
    align-items: flex-start;
    margin-bottom: 30px;
    margin-left: 30px;
    padding-bottom: 30px;
    border-left: 2px solid #ccc;
    &:first-of-type {
        margin-top: 30px;
    }
    &:last-of-type {
        margin-bottom: 0;
        border-left: none;
    }
    .stepNum {
        width: 30px;
        height: 30px;
        border-radius: 15px;
        box-sizing: border-box;
        color: #333;
        border: 1px solid #999;
        line-height: 28px;
        text-align: center;
        margin-right: 10px;
        margin-left: -16px;
        margin-top: -30px;
    }
    .stepCard {
        width: 100%;
        margin-top: -30px;

        .box-card {
            width: 100%;
            >>>.el-card__header {
                padding: 10px 15px;
            }
            .card-header {
                width: 100%;
                display: flex;
                justify-content: space-between;
                align-items: center;
                & > div:first-of-type {
                    margin-right: 80px;
                    font-size: 18px;
                    font-weight: bold;
                }
            }
        }
    }
    &:hover .card-header {
        color: #0098f5;
    }
    &:hover .stepNum {
        border: 2px solid #0098f5;
        color: #0098f5;
    }
}
.page-position{
    float: right;
    padding-top: 10px;
}
</style>
